@@ -223,7 +223,7 @@ gerbv_export_rs274x_file_from_image (const gchar *filename, gerbv_image_t *input
 	fprintf(fd, "G04 This is an RS-274x file exported by *\n");
 	fprintf(fd, "G04 gerbv version %s *\n",VERSION);
 	fprintf(fd, "G04 More information is available about gerbv at *\n");
-	fprintf(fd, "G04 http://gerbv.geda-project.org/ *\n");
+	fprintf(fd, "G04 https://gerbv.github.io/ *\n");
 	fprintf(fd, "G04 --End of header info--*\n");
 	fprintf(fd, "%%MOIN*%%\n");
 	fprintf(fd, "%%FSLAX36Y36*%%\n");
