@@ -1,6 +1,6 @@
 /*
  * gEDA - GNU Electronic Design Automation
- * This file is a part of gerbv.
+ * This file is a part of Gerbv.
  *
  *   Copyright (C) 2000-2003 Stefan Petersen (spe@stacken.kth.se)
  *
@@ -28,8 +28,11 @@
 //! \example example5.c
 //! \example example6.c
 
-//! \defgroup libgerbv libgerbv
 //! \defgroup gerbv Gerbv
+//! @{ Gerbv program @}
+
+//! \defgroup libgerbv libgerbv
+//! @{ Gerber library @}
 
 /** \file gerbv.h
     \brief The main header file for the libgerbv library
@@ -41,29 +44,29 @@
 
 \section intro_sec Introduction
 
-Gerbv is a program which can display, edit, export, and do other manipulation of
-file formats used in PCB design (RS274X, Excellon drill, and pick-and-place). The core
-library (libgerbv) is available as a separate library, allowing other software to easily
-incorporate advanced Gerber functionality.
+Gerbv is a program which can display, edit, export, and do other manipulation
+of file formats used in PCB design (RS274X, Excellon drill, and
+pick-and-place). The core library (libgerbv) is available as a separate
+library, allowing other software to easily incorporate advanced Gerber
+functionality.
 
-This code documentation is mainly intended to help explain the libgerbv API to developers
-wishing to use libgerbv in his/her own projects. The easiest way to learn to use libgerbv is
-by reading through and compiling the example source files (click on "Examples" in the navigation
-tree in the left pane, or look in the doc/example-code/ directory in CVS).
+This code documentation is mainly intended to help explain the libgerbv API to
+developers wishing to use libgerbv in his/her own projects. The easiest way to
+learn to use libgerbv is by reading through and compiling the example source
+files (click on "Examples" in the navigation tree in the left pane, or look in
+the doc/example-code/ directory in CVS).
+
+For help with using the standalone Gerbv software, please refer to the man page
+(using the command "man gerbv") or go to the Gerbv homepage for documentation
+(https://gerbv.github.io/).
 
-For help with using the standalone Gerbv software, please refer to the man page (using
-the command "man gerbv") or go to the Gerbv homepage for documentation (http://gerbv.sourceforge.net).
 */
 
 #ifndef __GERBV_H__
 #define __GERBV_H__
 
-#if defined(__cplusplus)
-extern "C" {
-#endif
-
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+# include "config.h"
 #endif
 
 #include <glib.h>
@@ -72,7 +75,11 @@ extern "C" {
 #include <gdk/gdkkeysyms.h>
 
 #ifndef RENDER_USING_GDK
-#include <cairo.h>
+# include <cairo.h>
+#endif
+
+#if defined(__cplusplus)
+extern "C" {
 #endif
 
 #define APERTURE_MIN 10
@@ -84,22 +91,35 @@ extern "C" {
  * So 50 points with x and y plus two for holding extra data gives...
  */
 #define APERTURE_PARAMETERS_MAX 102
-#define INITIAL_SCALE 200
+#define GERBV_SCALE_MIN 10
+#define GERBV_SCALE_MAX 3000
 #define MAX_ERRMSGLEN 25
 #define MAX_COORDLEN 28
-#define MAX_DISTLEN 90
+#define MAX_DISTLEN 180
 #define MAX_STATUSMSGLEN (MAX_ERRMSGLEN+MAX_COORDLEN+MAX_DISTLEN)
 
+/*
+ * Files only have a limited precision in their data, so when interpreting
+ * layer rotations or linear size that have been read from a project file, we
+ * have to tolerate a certain amount of error.
+ */
+#define GERBV_PRECISION_ANGLE_RAD	1e-6
+#define GERBV_PRECISION_LINEAR_INCH	1e-6
+
 /* Macros to convert between unscaled gerber coordinates and other units */
 /* XXX NOTE: Currently unscaled units are assumed as inch, this is not
    XXX necessarily true for all files */
+#define COORD2INS(c) (c)
 #define COORD2MILS(c) ((c)*1000.0)
 #define COORD2MMS(c) ((c)*25.4)
 
-#define GERB_FATAL_ERROR(t...) g_log(NULL, G_LOG_LEVEL_ERROR, ##t);
-#define GERB_COMPILE_ERROR(t...)  g_log(NULL, G_LOG_LEVEL_CRITICAL, ##t);
-#define GERB_COMPILE_WARNING(t...)  g_log(NULL, G_LOG_LEVEL_WARNING, ##t);
-#define GERB_MESSAGE(t...)  g_log(NULL, G_LOG_LEVEL_MESSAGE, ##t);
+#define DEG2RAD(d) ((d)*M_PI/180.0)
+#define RAD2DEG(r) ((r)*180.0*M_1_PI)
+
+#define GERB_FATAL_ERROR(...) g_log(NULL, G_LOG_LEVEL_ERROR, __VA_ARGS__)
+#define GERB_COMPILE_ERROR(...)  g_log(NULL, G_LOG_LEVEL_CRITICAL, __VA_ARGS__)
+#define GERB_COMPILE_WARNING(...)  g_log(NULL, G_LOG_LEVEL_WARNING, __VA_ARGS__)
+#define GERB_MESSAGE(...)  g_log(NULL, G_LOG_LEVEL_MESSAGE, __VA_ARGS__)
 
 /*! The aperture macro commands */  
 typedef enum {GERBV_OPCODE_NOP, /*!< no operation */
@@ -120,59 +140,152 @@ typedef enum {GERBV_MESSAGE_FATAL, /*!< processing cannot continue */
 		GERBV_MESSAGE_NOTE /*!< an irregularity was encountered, but needs no intervention */
 } gerbv_message_type_t;
 
-/*! The different aperture types available 
- *  Please keep these in sync with the aperture names defined by
- *  ap_names in callbacks.c */
-typedef enum {GERBV_APTYPE_NONE, /*!< no aperture used */
+/*! The different aperture types available.
+ *  Please keep these in sync with the aperture names defined in
+ *  gerbv_aperture_type_name() in gerbv.c */
+typedef enum {
+		GERBV_APTYPE_NONE, /*!< no aperture used */
 		GERBV_APTYPE_CIRCLE, /*!< a round aperture */
 		GERBV_APTYPE_RECTANGLE, /*!< a rectangular aperture */
 		GERBV_APTYPE_OVAL, /*!< an ovular (obround) aperture */
 		GERBV_APTYPE_POLYGON, /*!< a polygon aperture */
 		GERBV_APTYPE_MACRO, /*!< a RS274X macro */
-		GERBV_APTYPE_MACRO_CIRCLE, /*!< a RS274X circle macro */
-		GERBV_APTYPE_MACRO_OUTLINE, /*!< a RS274X outline macro */
-		GERBV_APTYPE_MACRO_POLYGON, /*!< a RS274X polygon macro */
-		GERBV_APTYPE_MACRO_MOIRE, /*!< a RS274X moire macro */
-		GERBV_APTYPE_MACRO_THERMAL, /*!< a RS274X thermal macro */
-		GERBV_APTYPE_MACRO_LINE20, /*!< a RS274X line (code 20) macro */
-		GERBV_APTYPE_MACRO_LINE21, /*!< a RS274X line (code 21) macro */
-		GERBV_APTYPE_MACRO_LINE22 /*!< a RS274X line (code 22) macro */
+			GERBV_APTYPE_MACRO_CIRCLE, /*!< a RS274X circle macro */
+			GERBV_APTYPE_MACRO_OUTLINE, /*!< a RS274X outline macro */
+			GERBV_APTYPE_MACRO_POLYGON, /*!< a RS274X polygon macro */
+			GERBV_APTYPE_MACRO_MOIRE, /*!< a RS274X moire macro */
+			GERBV_APTYPE_MACRO_THERMAL, /*!< a RS274X thermal macro */
+			GERBV_APTYPE_MACRO_LINE20, /*!< a RS274X vector line (code 20) macro */
+			GERBV_APTYPE_MACRO_LINE21, /*!< a RS274X centered line (code 21) macro */
+			GERBV_APTYPE_MACRO_LINE22 /*!< a RS274X lower left line (code 22) macro */
 } gerbv_aperture_type_t;
 
-/*! the current state of the aperture drawing tool */
+const char *gerbv_aperture_type_name(gerbv_aperture_type_t type);
+
+/*! The current state of the aperture drawing tool */
 typedef enum {GERBV_APERTURE_STATE_OFF, /*!< tool drawing is off, and nothing will be drawn */
 		GERBV_APERTURE_STATE_ON, /*!< tool drawing is on, and something will be drawn */
 		GERBV_APERTURE_STATE_FLASH /*!< tool is flashing, and will draw a single aperture */
 } gerbv_aperture_state_t;
 
-/*! the current unit used */
+/*! The circle aperture macro parameter indexes */
+typedef enum {
+		CIRCLE_EXPOSURE,
+		CIRCLE_DIAMETER,
+		CIRCLE_CENTER_X,
+		CIRCLE_CENTER_Y,
+} gerbv_aptype_macro_circle_index_t;
+
+typedef enum {
+		OUTLINE_EXPOSURE,
+		OUTLINE_NUMBER_OF_POINTS,
+		OUTLINE_FIRST_X, /* x0 */
+		OUTLINE_FIRST_Y, /* y0 */
+		/* x1, y1, x2, y2, ..., rotation */
+		OUTLINE_ROTATION, /* Rotation index is correct if outline has
+				     no point except first */
+} gerbv_aptype_macro_outline_index_t;
+
+/* Point number is from 0 (first) to (including) OUTLINE_NUMBER_OF_POINTS */
+#define OUTLINE_X_IDX_OF_POINT(number) (2*(number) + OUTLINE_FIRST_X)
+#define OUTLINE_Y_IDX_OF_POINT(number) (2*(number) + OUTLINE_FIRST_Y)
+#define	OUTLINE_ROTATION_IDX(param_array) \
+			((int)param_array[OUTLINE_NUMBER_OF_POINTS]*2 + \
+			OUTLINE_ROTATION)
+
+typedef enum {
+		POLYGON_EXPOSURE,
+		POLYGON_NUMBER_OF_POINTS,
+		POLYGON_CENTER_X,
+		POLYGON_CENTER_Y,
+		POLYGON_DIAMETER,
+		POLYGON_ROTATION,
+} gerbv_aptype_macro_polygon_index_t;
+
+typedef enum {
+		MOIRE_CENTER_X,
+		MOIRE_CENTER_Y,
+		MOIRE_OUTSIDE_DIAMETER,
+		MOIRE_CIRCLE_THICKNESS,
+		MOIRE_GAP_WIDTH,
+		MOIRE_NUMBER_OF_CIRCLES,
+		MOIRE_CROSSHAIR_THICKNESS,
+		MOIRE_CROSSHAIR_LENGTH,
+		MOIRE_ROTATION,
+} gerbv_aptype_macro_moire_index_t;
+
+typedef enum {
+		THERMAL_CENTER_X,
+		THERMAL_CENTER_Y,
+		THERMAL_OUTSIDE_DIAMETER,
+		THERMAL_INSIDE_DIAMETER,
+		THERMAL_CROSSHAIR_THICKNESS,
+		THERMAL_ROTATION,
+} gerbv_aptype_macro_thermal_index_t;
+
+/*! The vector line aperture macro parameter indexes */
+typedef enum {
+		LINE20_EXPOSURE,
+		LINE20_LINE_WIDTH,
+		LINE20_WIDTH = LINE20_LINE_WIDTH,	/* Unification alias */
+		LINE20_START_X,
+		LINE20_START_Y,
+		LINE20_END_X,
+		LINE20_END_Y,
+		LINE20_ROTATION,
+} gerbv_aptype_macro_line20_index_t;
+
+/*! The centered line aperture macro parameter indexes */
+typedef enum {
+		LINE21_EXPOSURE,
+		LINE21_WIDTH,
+		LINE21_HEIGHT,
+		LINE21_CENTER_X,
+		LINE21_CENTER_Y,
+		LINE21_ROTATION,
+} gerbv_aptype_macro_line21_index_t;
+
+/*! The lower left line aperture macro parameter indexes */
+typedef enum {
+		LINE22_EXPOSURE,
+		LINE22_WIDTH,
+		LINE22_HEIGHT,
+		LINE22_LOWER_LEFT_X,
+		LINE22_LOWER_LEFT_Y,
+		LINE22_ROTATION,
+} gerbv_aptype_macro_line22_index_t;
+
+
+/*! The current unit used */
 typedef enum {GERBV_UNIT_INCH, /*!< inches */
 		GERBV_UNIT_MM, /*!< mm */
 		GERBV_UNIT_UNSPECIFIED /*!< use default units */
 } gerbv_unit_t;
 
-/*! the different drawing polarities available */
+/*! The different drawing polarities available */
 typedef enum {GERBV_POLARITY_POSITIVE, /*!< draw "positive", using the current layer's polarity */
 		GERBV_POLARITY_NEGATIVE, /*!< draw "negative", reversing the current layer's polarity */
 		GERBV_POLARITY_DARK, /*!< add to the current rendering */
 		GERBV_POLARITY_CLEAR /*!< subtract from the current rendering */
 } gerbv_polarity_t;
 
-/*! the decimal point parsing style used */
+/*! The decimal point parsing style used */
 typedef enum {GERBV_OMIT_ZEROS_LEADING, /*!< omit extra zeros before the decimal point */
 		GERBV_OMIT_ZEROS_TRAILING, /*!< omit extra zeros after the decimal point */
 		GERBV_OMIT_ZEROS_EXPLICIT, /*!< explicitly specify how many decimal places are used */
 		GERBV_OMIT_ZEROS_UNSPECIFIED /*!< use the default parsing style */
 } gerbv_omit_zeros_t;
 
-/*! the coordinate system used */
+/*! The coordinate system used */
 typedef enum {GERBV_COORDINATE_ABSOLUTE, /*!< all coordinates are absolute from a common origin */
 		GERBV_COORDINATE_INCREMENTAL /*!< all coordinates are relative to the previous coordinate */
 } gerbv_coordinate_t;
 
-/*! the interpolation methods available */
+/*! The interpolation methods available.
+ *  Please keep these in sync with the interpolation names defined in
+ *  gerbv_interpolation_name() in gerbv.c */
 typedef enum {GERBV_INTERPOLATION_LINEARx1, /*!< draw a line */
-		GERBV_INTERPOLATION_x10, /*!< draw a line */
+		GERBV_INTERPOLATION_LINEARx10, /*!< draw a line */
 		GERBV_INTERPOLATION_LINEARx01, /*!< draw a line */
 		GERBV_INTERPOLATION_LINEARx001, /*!< draw a line */
 		GERBV_INTERPOLATION_CW_CIRCULAR, /*!< draw an arc in the clockwise direction */
@@ -182,6 +295,11 @@ typedef enum {GERBV_INTERPOLATION_LINEARx1, /*!< draw a line */
 		GERBV_INTERPOLATION_DELETED /*!< the net has been deleted by the user, and will not be drawn */
 } gerbv_interpolation_t;
 
+/* For backward compatibility */
+enum {GERBV_INTERPOLATION_x10 = GERBV_INTERPOLATION_LINEARx10};
+
+const char *gerbv_interpolation_name(gerbv_interpolation_t interp);
+
 typedef enum {GERBV_ENCODING_NONE,
 		GERBV_ENCODING_ASCII,
 		GERBV_ENCODING_EBCDIC,
@@ -191,9 +309,11 @@ typedef enum {GERBV_ENCODING_NONE,
 } gerbv_encoding_t;
 
 /*! The different layer types used */
-typedef enum {GERBV_LAYERTYPE_RS274X, /*!< the file is a RS274X file */
+typedef enum {
+		GERBV_LAYERTYPE_RS274X, /*!< the file is a RS274X file */
 		GERBV_LAYERTYPE_DRILL, /*!< the file is an Excellon drill file */
-		GERBV_LAYERTYPE_PICKANDPLACE /*!< the file is a CSV pick and place file */
+		GERBV_LAYERTYPE_PICKANDPLACE_TOP, /*!< the file is a CSV pick and place file, top side */
+		GERBV_LAYERTYPE_PICKANDPLACE_BOT, /*!< the file is a CSV pick and place file, bottom side */
 } gerbv_layertype_t;
 
 typedef enum {GERBV_KNOCKOUT_TYPE_NOKNOCKOUT,
@@ -217,11 +337,17 @@ typedef enum {GERBV_JUSTIFY_NOJUSTIFY,
 } gerbv_image_justify_type_t;
 
 /*! The different selection modes available */
-typedef enum {GERBV_SELECTION_EMPTY, /*!< the selection buffer is empty */
-		GERBV_SELECTION_POINT_CLICK, /*!< the user clicked on a single point */
+typedef enum {	GERBV_SELECTION_POINT_CLICK = 1, /*!< the user clicked on a single point */
 		GERBV_SELECTION_DRAG_BOX /*!< the user dragged a box to encompass one or more objects */
 } gerbv_selection_t;
 
+enum draw_mode {
+	DRAW_IMAGE = 0,
+	DRAW_SELECTIONS,
+	FIND_SELECTIONS,
+	FIND_SELECTIONS_TOGGLE,
+};
+
 /*! The different rendering modes available to libgerbv */
 typedef enum {GERBV_RENDER_TYPE_GDK, /*!< render using normal GDK drawing functions */
 		GERBV_RENDER_TYPE_GDK_XOR, /*!< use the GDK_XOR mask to draw a pseudo-transparent scene */
@@ -393,6 +519,7 @@ typedef struct {
     int G03;
     int G04;
     int G05;
+    int G85;
     int G90;
     int G91;
     int G93;
@@ -426,8 +553,8 @@ typedef struct {
 } gerbv_drill_stats_t;
 
 typedef struct {
-	gpointer image;
-	gpointer net;
+	gpointer image;		/* gerbv_image_t* */
+	gpointer net;		/* gerbv_net_t* */
 } gerbv_selection_item_t;
 
 /*! Struct holding info about the last selection */
@@ -462,12 +589,12 @@ typedef struct {
 } gerbv_render_size_t;
 
 typedef struct gerbv_cirseg {
-    double cp_x;
-    double cp_y;
-    double width;  /* of oval */
-    double height; /* of oval */
-    double angle1;
-    double angle2;
+    double cp_x;   /* center point x */
+    double cp_y;   /* center point y */
+    double width;  /* used as diameter */
+    double height; /* */
+    double angle1; /* in degrees */
+    double angle2; /* in degrees */
 } gerbv_cirseg_t;
 
 typedef struct gerbv_step_and_repeat { /* SR parameters */
@@ -602,11 +729,6 @@ typedef struct {
   gboolean layer_dirty;  /*!< True if layer has been modified since last save */
 } gerbv_fileinfo_t;
 
-typedef struct {
-	double x1, y1;
-	double x2, y2;
-} gerbv_bbox_t;
-
 /*!  The top-level structure used in libgerbv.  A gerbv_project_t groups together
 any number of layers, while keeping track of other basic paramters needed for rendering */
 typedef struct {
@@ -614,12 +736,13 @@ typedef struct {
   int max_files; /*!< the current number of fileinfos in the file array */
   gerbv_fileinfo_t **file; /*!< the array for holding the child fileinfos */
   int curr_index; /*!< the index of the currently active fileinfo */
-  int last_loaded; /*!< the number of fileinfos currently in the project */
+  int last_loaded; /*!< the (number-1) of fileinfos currently in the project */
   int renderType; /*!< the type of renderer to use */
   gboolean check_before_delete;  /*!< TRUE to ask before deleting objects */
+  gboolean show_invisible_selection; /*!< TRUE to show selected objects on invisible files */
   gchar *path; /*!< the default path to load new files from */
-  gchar *execpath;    /*!< the path to executed version of gerbv */
-  gchar *execname;    /*!< the path plus executible name for gerbv */
+  gchar *execpath;    /*!< the path to executed version of Gerbv */
+  gchar *execname;    /*!< the path plus executible name for Gerbv */
   gchar *project;     /*!< the default name for the private project file */
 } gerbv_project_t;
 
@@ -640,6 +763,7 @@ typedef struct {
 	gerbv_render_types_t renderType; /*!< the type of rendering to use */
 	gint displayWidth; /*!< the width of the scene (in pixels, or points depending on the surface type) */
 	gint displayHeight; /*!< the height of the scene (in pixels, or points depending on the surface type) */
+	gboolean show_cross_on_drill_holes; /*!< TRUE to show cross on drill holes */
 } gerbv_render_info_t;
 
 //! Allocate a new gerbv_image structure
@@ -671,9 +795,6 @@ void
 gerbv_image_delete_net (gerbv_net_t *currentNet /*!< the net to delete */
 );
 
-void
-gerbv_image_delete_selected_nets (gerbv_image_t *sourceImage, GArray *selectedNodeArray);
-
 gboolean
 gerbv_image_reduce_area_of_selected_objects (GArray *selectionArray, gdouble areaReduction, gint paneRows,
 		gint paneColumns, gdouble paneSeparation);
@@ -852,6 +973,14 @@ gerbv_export_svg_file_from_project (
 		gchar const* filename /*!< the filename for the exported   file */
 );
 
+//! Export an image to a new file in DXF format
+//! \return TRUE if successful, or FALSE if not
+gboolean
+gerbv_export_dxf_file_from_image (const gchar *filename, /*!< the filename for the new file */
+		gerbv_image_t *image, /*!< the image to export */
+		gerbv_user_transformation_t *transform /*!< the transformation to apply before exporting */
+);
+
 //! Parse a RS274X file and return the parsed image
 //! \return the new gerbv_image_t, or NULL if not successful
 gerbv_image_t *
@@ -861,7 +990,7 @@ gerbv_create_rs274x_image_from_filename (gchar *filename /*!< the filename of th
 //! Export an image to a new file in RS274X format
 //! \return TRUE if successful, or FALSE if not
 gboolean
-gerbv_export_rs274x_file_from_image (gchar *filename, /*!< the filename for the new file */
+gerbv_export_rs274x_file_from_image (const gchar *filename, /*!< the filename for the new file */
 		gerbv_image_t *image, /*!< the image to export */
 		gerbv_user_transformation_t *transform /*!< the transformation to apply before exporting */
 );
@@ -869,7 +998,23 @@ gerbv_export_rs274x_file_from_image (gchar *filename, /*!< the filename for the
 //! Export an image to a new file in Excellon drill format
 //! \return TRUE if successful, or FALSE if not
 gboolean
-gerbv_export_drill_file_from_image (gchar *filename, /*!< the filename for the new file */
+gerbv_export_drill_file_from_image (const gchar *filename, /*!< the filename for the new file */
+		gerbv_image_t *image, /*!< the image to export */
+		gerbv_user_transformation_t *transform /*!< the transformation to apply before exporting */
+);
+
+//! Export an image to a new file in ISEL NCP drill format
+//! \return TRUE if successful, or FALSE if not
+gboolean
+gerbv_export_isel_drill_file_from_image (const gchar *filename, /*!< the filename for the new file */
+		gerbv_image_t *image, /*!< the image to export */
+		gerbv_user_transformation_t *transform /*!< the transformation to apply before exporting */
+);
+
+//! Export an image to a new file in gEDA PCB format
+//! \return TRUE if successful, or FALSE if not
+gboolean
+gerbv_export_geda_pcb_file_from_image (const gchar *filename, /*!< the filename for the new file */
 		gerbv_image_t *image, /*!< the image to export */
 		gerbv_user_transformation_t *transform /*!< the transformation to apply before exporting */
 );
@@ -949,6 +1094,38 @@ gerbv_attribute_destroy_HID_attribute (gerbv_HID_Attribute *attributeList, int n
 gerbv_HID_Attribute *
 gerbv_attribute_dup (gerbv_HID_Attribute *, int);
 
+/*! Return found fileinfo for image, or NULL */
+gerbv_fileinfo_t *
+gerbv_get_fileinfo_for_image(const gerbv_image_t *image,
+				const gerbv_project_t *project);
+
+/*! Transform coordinate x and y for image in project */
+int
+gerbv_transform_coord_for_image(double *x, double *y,
+		const gerbv_image_t *image, const gerbv_project_t *project);
+
+/*! Transform coordinate x and y */
+void
+gerbv_transform_coord(double *x, double *y,
+		const gerbv_user_transformation_t *trans);
+
+/*! Rotate coordinate x and y buy angle in radians */
+void
+gerbv_rotate_coord(double *x, double *y, double rad);
+
+#undef MIN
+#undef MAX
+#define MIN(x,y) ({ \
+		typeof(x) _x = (x);     \
+		typeof(y) _y = (y);     \
+		(void) (&_x == &_y);    \
+		_x < _y ? _x : _y; })
+#define MAX(x,y) ({ \
+		typeof(x) _x = (x);     \
+		typeof(y) _y = (y);     \
+		(void) (&_x == &_y);    \
+		_x > _y ? _x : _y; })
+
 #if defined(__cplusplus)
 }
 #endif
